# ORSCF-StudyManagement Schema Specification

|          | Info                                    |
|----------|-----------------------------------------|
|author:   |[ORSCF](https://www.orscf.org) ("Open Research Study Communication Formats") / T.Korn|
|license:  |[Apache-2](https://choosealicense.com/licenses/apache-2.0/)|
|version:  |1.6.0|
|timestamp:|2021-11-28 00:00|

### Contents

  * .  [Institute](#Institute)
  * ........\  [InstituteRelatedSystemAssignment](#InstituteRelatedSystemAssignment)
  * ........\  [SystemConnection](#SystemConnection)
  * ........\  [SystemEndpoint](#SystemEndpoint)
  * .  [InvolvedPerson](#InvolvedPerson)
  * .  [ResearchStudy](#ResearchStudy)
  * ........\  [InvolvementRole](#InvolvementRole)
  * ........\  [Site](#Site)
  * ................\  [SiteRelatedSystemAssignment](#SiteRelatedSystemAssignment)
  * ........\  [StudyRelatedSystemAssignment](#StudyRelatedSystemAssignment)

# Model:

![chart](./chart.png)



## Institute


### Fields

| Name | Type | Required | Fix |
| ---- | ---- | -------- | --- |
| [InstituteUid](#InstituteInstituteUid-Field) **(PK)** | *guid* | YES | no |
| [DisplayLabel](#InstituteDisplayLabel-Field) | *string* (100) | YES | no |
| IsArchived | *boolean* | YES | no |
#### Unique Keys
* InstituteUid **(primary)**

#### Institute.**InstituteUid** (Field)

An [Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) which can be generated by any origin system and is used to address this ORSCF conform data record in decentralized environments. Note that this Identity must not be changed any more!

* this field represents the identity (PK) of the record

#### Institute.**DisplayLabel** (Field)

An DisplayLabel which is dedicated for the usage within the frontend of study managent software. Note that this short name representation hat the caracter of an internal shortcurt and could be ambiguous. The usage for legal-relevant/official communication or documents is not recommended, as well as the usage for technical identification of this record.

* the maximum length of the content within this field is 100 characters.


### Relations

| Navigation-Name | Role | Target-Type | Target-Multiplicity |
| --------------- | -----| ----------- | ------------------- |
| [InitiatedStudies](#InitiatedStudies-refering-to-this-Institute) | Referers | [ResearchStudy](#ResearchStudy) | * (multiple) |
| [RepresentedSites](#RepresentedSites-refering-to-this-Institute) | Referers | [Site](#Site) | * (multiple) |
| [ProvidedSystemEndpoints](#ProvidedSystemEndpoints-childs-of-this-Institute) | Childs | [SystemEndpoint](#SystemEndpoint) | * (multiple) |
| [SystemAssignment](#SystemAssignment-childs-of-this-Institute) | Childs | [InstituteRelatedSystemAssignment](#InstituteRelatedSystemAssignment) | * (multiple) |
| [SystemConnections](#SystemConnections-childs-of-this-Institute) | Childs | [SystemConnection](#SystemConnection) | * (multiple) |

##### **InitiatedStudies** (refering to this Institute)
Target: [ResearchStudy](#ResearchStudy)
##### **RepresentedSites** (refering to this Institute)
Target: [Site](#Site)
##### **ProvidedSystemEndpoints** (childs of this Institute)
Target: [SystemEndpoint](#SystemEndpoint)
##### **SystemAssignment** (childs of this Institute)
Target: [InstituteRelatedSystemAssignment](#InstituteRelatedSystemAssignment)
##### **SystemConnections** (childs of this Institute)
Target: [SystemConnection](#SystemConnection)




## InstituteRelatedSystemAssignment


### Fields

| Name | Type | Required | Fix |
| ---- | ---- | -------- | --- |
| [InstituteRelatedSystemAssignemntUid](#InstituteRelatedSystemAssignmentInstituteRelatedSystemAssignemntUid-Field) **(PK)** | *guid* | YES | no |
| [SystemEndpointUid](#InstituteRelatedSystemAssignmentSystemEndpointUid-Field) (FK) | *guid* | YES | no |
| [InstituteUid](#InstituteRelatedSystemAssignmentInstituteUid-Field) (FK) | *guid* | YES | no |
| UseAsOwnPatientSdr | *string* | YES | no |
| UseAsCandidateSdr | *string* | YES | no |
| UseAsOwnWdr | *string* | YES | no |
| UseAsConsumingExternalWdr | *string* | YES | no |
| [CustomRoles](#InstituteRelatedSystemAssignmentCustomRoles-Field) | *string* | YES | no |
#### Unique Keys
* InstituteRelatedSystemAssignemntUid **(primary)**

#### InstituteRelatedSystemAssignment.**InstituteRelatedSystemAssignemntUid** (Field)
* this field represents the identity (PK) of the record

#### InstituteRelatedSystemAssignment.**SystemEndpointUid** (Field)
* this field is used as foreign key to address the related 'SystemEndpoint'

#### InstituteRelatedSystemAssignment.**InstituteUid** (Field)
* this field is used as foreign key to address the related 'Institute'

#### InstituteRelatedSystemAssignment.**CustomRoles** (Field)

semicolon separated list of custom role-names



### Relations

| Navigation-Name | Role | Target-Type | Target-Multiplicity |
| --------------- | -----| ----------- | ------------------- |
| [Institute](#Institute-parent-of-this-InstituteRelatedSystemAssignment) | Parent | [Institute](#Institute) | 0/1 (optional) |
| [SystemEndpoint](#SystemEndpoint-lookup-from-this-InstituteRelatedSystemAssignment) | Lookup | [SystemEndpoint](#SystemEndpoint) | 0/1 (optional) |

##### **Institute** (parent of this InstituteRelatedSystemAssignment)
Target Type: [Institute](#Institute)
Addressed by: [InstituteUid](#InstituteRelatedSystemAssignmentInstituteUid-Field).
##### **SystemEndpoint** (lookup from this InstituteRelatedSystemAssignment)
Target Type: [SystemEndpoint](#SystemEndpoint)
Addressed by: [SystemEndpointUid](#InstituteRelatedSystemAssignmentSystemEndpointUid-Field).




## SystemConnection


### Fields

| Name | Type | Required | Fix |
| ---- | ---- | -------- | --- |
| [SystemConnectionUid](#SystemConnectionSystemConnectionUid-Field) **(PK)** | *guid* | YES | no |
| [OwnerInstituteUid](#SystemConnectionOwnerInstituteUid-Field) (FK) | *guid* | YES | no |
| HierSpterJWTSEttings | *string* | YES | no |
| [TargetSystemEndpointUid](#SystemConnectionTargetSystemEndpointUid-Field) (FK) | *guid* | YES | no |
| [DedicatedSiteRelatedSystemAssignmentUid](#SystemConnectionDedicatedSiteRelatedSystemAssignmentUid-Field) (FK) | *guid* | no | no |
#### Unique Keys
* SystemConnectionUid **(primary)**

#### SystemConnection.**SystemConnectionUid** (Field)
* this field represents the identity (PK) of the record

#### SystemConnection.**OwnerInstituteUid** (Field)
* this field is used as foreign key to address the related 'OwnerInstitute'

#### SystemConnection.**TargetSystemEndpointUid** (Field)
* this field is used as foreign key to address the related 'TargetEndpoint'

#### SystemConnection.**DedicatedSiteRelatedSystemAssignmentUid** (Field)
* this field is optional, so that '*null*' values are supported
* this field is used as foreign key to address the related 'DedicatedSiteRelatedSystemAssignment'


### Relations

| Navigation-Name | Role | Target-Type | Target-Multiplicity |
| --------------- | -----| ----------- | ------------------- |
| [OwnerInstitute](#OwnerInstitute-parent-of-this-SystemConnection) | Parent | [Institute](#Institute) | 0/1 (optional) |
| [DedicatedSiteRelatedSystemAssignment](#DedicatedSiteRelatedSystemAssignment-lookup-from-this-SystemConnection) | Lookup | [SiteRelatedSystemAssignment](#SiteRelatedSystemAssignment) | 1 (required) |
| [TargetEndpoint](#TargetEndpoint-lookup-from-this-SystemConnection) | Lookup | [SystemEndpoint](#SystemEndpoint) | 0/1 (optional) |

##### **OwnerInstitute** (parent of this SystemConnection)
Target Type: [Institute](#Institute)
Addressed by: [OwnerInstituteUid](#SystemConnectionOwnerInstituteUid-Field).
##### **DedicatedSiteRelatedSystemAssignment** (lookup from this SystemConnection)
Target Type: [SiteRelatedSystemAssignment](#SiteRelatedSystemAssignment)
Addressed by: [DedicatedSiteRelatedSystemAssignmentUid](#SystemConnectionDedicatedSiteRelatedSystemAssignmentUid-Field).
##### **TargetEndpoint** (lookup from this SystemConnection)
Target Type: [SystemEndpoint](#SystemEndpoint)
Addressed by: [TargetSystemEndpointUid](#SystemConnectionTargetSystemEndpointUid-Field).




## SystemEndpoint


### Fields

| Name | Type | Required | Fix |
| ---- | ---- | -------- | --- |
| [SystemEndpointUid](#SystemEndpointSystemEndpointUid-Field) **(PK)** | *guid* | YES | no |
| [ProviderInstituteUid](#SystemEndpointProviderInstituteUid-Field) (FK) | *guid* | YES | no |
| AvailableRoles | *string* | YES | no |
| Url | *string* | YES | no |
| ApprovedCert | *string* | YES | no |
| IsPublic | *string* | YES | no |
| Label | *string* | YES | no |
#### Unique Keys
* SystemEndpointUid **(primary)**

#### SystemEndpoint.**SystemEndpointUid** (Field)
* this field represents the identity (PK) of the record

#### SystemEndpoint.**ProviderInstituteUid** (Field)
* this field is used as foreign key to address the related 'ProviderInstitute'


### Relations

| Navigation-Name | Role | Target-Type | Target-Multiplicity |
| --------------- | -----| ----------- | ------------------- |
| [ProviderInstitute](#ProviderInstitute-parent-of-this-SystemEndpoint) | Parent | [Institute](#Institute) | 0/1 (optional) |
| [InstituteAssignments](#InstituteAssignments-refering-to-this-SystemEndpoint) | Referers | [InstituteRelatedSystemAssignment](#InstituteRelatedSystemAssignment) | * (multiple) |
| [SiteAssignments](#SiteAssignments-refering-to-this-SystemEndpoint) | Referers | [SiteRelatedSystemAssignment](#SiteRelatedSystemAssignment) | * (multiple) |
| [StudyAssignments](#StudyAssignments-refering-to-this-SystemEndpoint) | Referers | [StudyRelatedSystemAssignment](#StudyRelatedSystemAssignment) | * (multiple) |

##### **ProviderInstitute** (parent of this SystemEndpoint)
Target Type: [Institute](#Institute)
Addressed by: [ProviderInstituteUid](#SystemEndpointProviderInstituteUid-Field).
##### **InstituteAssignments** (refering to this SystemEndpoint)
Target: [InstituteRelatedSystemAssignment](#InstituteRelatedSystemAssignment)
##### **SiteAssignments** (refering to this SystemEndpoint)
Target: [SiteRelatedSystemAssignment](#SiteRelatedSystemAssignment)
##### **StudyAssignments** (refering to this SystemEndpoint)
Target: [StudyRelatedSystemAssignment](#StudyRelatedSystemAssignment)




## InvolvedPerson


### Fields

| Name | Type | Required | Fix |
| ---- | ---- | -------- | --- |
| [InvolvedPersonUid](#InvolvedPersonInvolvedPersonUid-Field) **(PK)** | *guid* | YES | no |
| [DisplayLabel](#InvolvedPersonDisplayLabel-Field) | *string* | no | no |
| [EmailAddress](#InvolvedPersonEmailAddress-Field) | *guid* | no | no |
| IsArchived | *boolean* | YES | no |
#### Unique Keys
* InvolvedPersonUid **(primary)**

#### InvolvedPerson.**InvolvedPersonUid** (Field)

An [Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) which can be generated by any origin system and is used to address this ORSCF conform data record in decentralized environments. Note that this Identity must not be changed any more!

* this field represents the identity (PK) of the record

#### InvolvedPerson.**DisplayLabel** (Field)
* this field is optional, so that '*null*' values are supported

#### InvolvedPerson.**EmailAddress** (Field)
* this field is optional, so that '*null*' values are supported


### Relations

| Navigation-Name | Role | Target-Type | Target-Multiplicity |
| --------------- | -----| ----------- | ------------------- |
| [InvolvementRoles](#InvolvementRoles-refering-to-this-InvolvedPerson) | Referers | [InvolvementRole](#InvolvementRole) | * (multiple) |

##### **InvolvementRoles** (refering to this InvolvedPerson)
Target: [InvolvementRole](#InvolvementRole)




## ResearchStudy

entity, which relates to [HL7.ResearchStudy](https://www.hl7.org/fhir/researchstudy.html)
### Fields

| Name | Type | Required | Fix |
| ---- | ---- | -------- | --- |
| [ResearchStudyUid](#ResearchStudyResearchStudyUid-Field) **(PK)** | *guid* | YES | no |
| [DisplayLabel](#ResearchStudyDisplayLabel-Field) | *string* (100) | YES | no |
| [InitiatorInstituteUid](#ResearchStudyInitiatorInstituteUid-Field) (FK) | *guid* | YES | no |
| StudyWorkflowName | *string* | YES | no |
| StudyWorkflowVersion | *string* | YES | no |
| [Phase](#ResearchStudyPhase-Field) | *string* | no | no |
| [StartDate](#ResearchStudyStartDate-Field) | *datetime* | no | no |
| [TerminationDate](#ResearchStudyTerminationDate-Field) | *datetime* | no | no |
| [SubjectIdentifierTitle](#ResearchStudySubjectIdentifierTitle-Field) | *string* | YES | no |
| [Status](#ResearchStudyStatus-Field) | *string* | YES | no |
| [TerminatedReason](#ResearchStudyTerminatedReason-Field) | *string* | no | no |
| IsArchived | *boolean* | YES | no |
| [InitiatorRelatedProjectNumber](#ResearchStudyInitiatorRelatedProjectNumber-Field) | *string* | no | no |
| [OriginWdrEndpointUid](#ResearchStudyOriginWdrEndpointUid-Field) (FK) | *guid* | no | no |
#### Unique Keys
* ResearchStudyUid **(primary)**

#### ResearchStudy.**ResearchStudyUid** (Field)

An [Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) which can be generated by any origin system and is used to address this ORSCF conform data record in decentralized environments. Note that this Identity must not be changed any more!

* this field represents the identity (PK) of the record

#### ResearchStudy.**DisplayLabel** (Field)

An DisplayLabel which is dedicated for the usage within the frontend of study managent software. Note that this short name representation hat the caracter of an internal shortcurt and could be ambiguous. The usage for legal-relevant/official communication or documents is not recommended, as well as the usage for technical identification of this record.

* the maximum length of the content within this field is 100 characters.

#### ResearchStudy.**InitiatorInstituteUid** (Field)
* this field is used as foreign key to address the related 'InitiatorInstitute'

#### ResearchStudy.**Phase** (Field)

AS DECLARED BY [HL7.ResearchStudyPhase](https://www.hl7.org/fhir/valueset-research-study-phase.html):
n-a | early-phase-1 | phase-1 | phase-1-phase-2 | phase-2 | phase-2-phase-3 | phase-3 | phase-4

* this field is optional, so that '*null*' values are supported

#### ResearchStudy.**StartDate** (Field)

a estimated date in future is possible

* this field is optional, so that '*null*' values are supported

#### ResearchStudy.**TerminationDate** (Field)

a estimated date in future is possible

* this field is optional, so that '*null*' values are supported

#### ResearchStudy.**SubjectIdentifierTitle** (Field)

A title which informs about the sematic of the SubjectIdentifer (which concrete value is used): "Randomization-Number", "Screening-Number", ...


#### ResearchStudy.**Status** (Field)

AS DECLARED BY [HL7.ResearchStudyStatus](https://www.hl7.org/fhir/valueset-research-study-status.html):
active | administratively-completed | approved | closed-to-accrual | closed-to-accrual-and-intervention | completed | disapproved | in-review | temporarily-closed-to-accrual | temporarily-closed-to-accrual-and-intervention | withdrawn


#### ResearchStudy.**TerminatedReason** (Field)
* this field is optional, so that '*null*' values are supported

#### ResearchStudy.**InitiatorRelatedProjectNumber** (Field)
* this field is optional, so that '*null*' values are supported

#### ResearchStudy.**OriginWdrEndpointUid** (Field)
* this field is optional, so that '*null*' values are supported
* this field is used as foreign key to address the related 'OriginWdr'


### Relations

| Navigation-Name | Role | Target-Type | Target-Multiplicity |
| --------------- | -----| ----------- | ------------------- |
| [InitiatorInstitute](#InitiatorInstitute-lookup-from-this-ResearchStudy) | Lookup | [Institute](#Institute) | 0/1 (optional) |
| [InvolvementRoles](#InvolvementRoles-childs-of-this-ResearchStudy) | Childs | [InvolvementRole](#InvolvementRole) | * (multiple) |
| [Sites](#Sites-childs-of-this-ResearchStudy) | Childs | [Site](#Site) | * (multiple) |
| [OriginWdr](#OriginWdr-lookup-from-this-ResearchStudy) | Lookup | [SystemEndpoint](#SystemEndpoint) | 1 (required) |
| [SystemAssignments](#SystemAssignments-childs-of-this-ResearchStudy) | Childs | [StudyRelatedSystemAssignment](#StudyRelatedSystemAssignment) | * (multiple) |

##### **InitiatorInstitute** (lookup from this ResearchStudy)
Target Type: [Institute](#Institute)
Addressed by: [InitiatorInstituteUid](#ResearchStudyInitiatorInstituteUid-Field).
##### **InvolvementRoles** (childs of this ResearchStudy)
Target: [InvolvementRole](#InvolvementRole)
##### **Sites** (childs of this ResearchStudy)
Target: [Site](#Site)
##### **OriginWdr** (lookup from this ResearchStudy)
Target Type: [SystemEndpoint](#SystemEndpoint)
Addressed by: [OriginWdrEndpointUid](#ResearchStudyOriginWdrEndpointUid-Field).
##### **SystemAssignments** (childs of this ResearchStudy)
Target: [StudyRelatedSystemAssignment](#StudyRelatedSystemAssignment)




## InvolvementRole


### Fields

| Name | Type | Required | Fix |
| ---- | ---- | -------- | --- |
| [InvolvedPersonRoleUid](#InvolvementRoleInvolvedPersonRoleUid-Field) **(PK)** | *guid* | YES | no |
| [ResearchStudyUid](#InvolvementRoleResearchStudyUid-Field) (FK) | *guid* | YES | no |
| [Role](#InvolvementRoleRole-Field) | *string* | no | no |
| [InvolvedFrom](#InvolvementRoleInvolvedFrom-Field) | *datetime* | no | no |
| [InvolvedUntil](#InvolvementRoleInvolvedUntil-Field) | *datetime* | no | no |
| [DedicatedToSiteUid](#InvolvementRoleDedicatedToSiteUid-Field) (FK) | *guid* | no | no |
| [InvolvedPersonUid](#InvolvementRoleInvolvedPersonUid-Field) (FK) | *guid* | YES | no |
#### Unique Keys
* InvolvedPersonRoleUid **(primary)**

#### InvolvementRole.**InvolvedPersonRoleUid** (Field)

An [Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) which can be generated by any origin system and is used to address this ORSCF conform data record in decentralized environments. Note that this Identity must not be changed any more!

* this field represents the identity (PK) of the record

#### InvolvementRole.**ResearchStudyUid** (Field)
* this field is used as foreign key to address the related 'ResearchStudy'

#### InvolvementRole.**Role** (Field)
* this field is optional, so that '*null*' values are supported

#### InvolvementRole.**InvolvedFrom** (Field)
* this field is optional, so that '*null*' values are supported

#### InvolvementRole.**InvolvedUntil** (Field)
* this field is optional, so that '*null*' values are supported

#### InvolvementRole.**DedicatedToSiteUid** (Field)

null indicated a site independent global role

* this field is optional, so that '*null*' values are supported
* this field is used as foreign key to address the related 'DedicatedToSite'

#### InvolvementRole.**InvolvedPersonUid** (Field)
* this field is used as foreign key to address the related 'InvolvedPerson'


### Relations

| Navigation-Name | Role | Target-Type | Target-Multiplicity |
| --------------- | -----| ----------- | ------------------- |
| [InvolvedPerson](#InvolvedPerson-lookup-from-this-InvolvementRole) | Lookup | [InvolvedPerson](#InvolvedPerson) | 0/1 (optional) |
| [ResearchStudy](#ResearchStudy-parent-of-this-InvolvementRole) | Parent | [ResearchStudy](#ResearchStudy) | 0/1 (optional) |
| [DedicatedToSite](#DedicatedToSite-lookup-from-this-InvolvementRole) | Lookup | [Site](#Site) | 1 (required) |

##### **InvolvedPerson** (lookup from this InvolvementRole)
Target Type: [InvolvedPerson](#InvolvedPerson)
Addressed by: [InvolvedPersonUid](#InvolvementRoleInvolvedPersonUid-Field).
##### **ResearchStudy** (parent of this InvolvementRole)
Target Type: [ResearchStudy](#ResearchStudy)
Addressed by: [ResearchStudyUid](#InvolvementRoleResearchStudyUid-Field).
##### **DedicatedToSite** (lookup from this InvolvementRole)
Target Type: [Site](#Site)
Addressed by: [DedicatedToSiteUid](#InvolvementRoleDedicatedToSiteUid-Field).




## Site


### Fields

| Name | Type | Required | Fix |
| ---- | ---- | -------- | --- |
| [SiteUid](#SiteSiteUid-Field) **(PK)** | *guid* | YES | no |
| [RepresentingInstituteUid](#SiteRepresentingInstituteUid-Field) (FK) | *guid* | YES | no |
| [ResearchStudyUid](#SiteResearchStudyUid-Field) (FK) | *guid* | YES | no |
| [EnrollmentDate](#SiteEnrollmentDate-Field) | *datetime* | no | no |
| [TerminationDate](#SiteTerminationDate-Field) | *datetime* | no | no |
| [TerminatedReason](#SiteTerminatedReason-Field) | *string* | no | no |
| [StudyRelatedSiteIdentifer](#SiteStudyRelatedSiteIdentifer-Field) | *string* | YES | no |
| [DisplayLabel](#SiteDisplayLabel-Field) | *string* | YES | no |
| [Status](#SiteStatus-Field) | *string* | YES | no |
| [SiteRelatedProjectNumber](#SiteSiteRelatedProjectNumber-Field) | *string* | no | no |
#### Unique Keys
* SiteUid **(primary)**

#### Site.**SiteUid** (Field)

An [Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) which can be generated by any origin system and is used to address this ORSCF conform data record in decentralized environments. Note that this Identity must not be changed any more!

* this field represents the identity (PK) of the record

#### Site.**RepresentingInstituteUid** (Field)

[Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) of the institute, which is representing this site

* this field is used as foreign key to address the related 'RepresentingInstitute'

#### Site.**ResearchStudyUid** (Field)

[Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) of the related record

* this field is used as foreign key to address the related 'Study'

#### Site.**EnrollmentDate** (Field)

a estimated date in future is possible

* this field is optional, so that '*null*' values are supported

#### Site.**TerminationDate** (Field)

a estimated date in future is possible

* this field is optional, so that '*null*' values are supported

#### Site.**TerminatedReason** (Field)
* this field is optional, so that '*null*' values are supported

#### Site.**StudyRelatedSiteIdentifer** (Field)

Offical 'SiteIdentifier' which is unique within the scope of the related study


#### Site.**DisplayLabel** (Field)

An DisplayLabel which is dedicated for the usage within the frontend of study managent software. Note that this short name representation hat the caracter of an internal shortcurt and could be ambiguous. The usage for legal-relevant/official communication or documents is not recommended, as well as the usage for technical identification of this record.


#### Site.**Status** (Field)

AS DECLARED BY HL7


#### Site.**SiteRelatedProjectNumber** (Field)
* this field is optional, so that '*null*' values are supported


### Relations

| Navigation-Name | Role | Target-Type | Target-Multiplicity |
| --------------- | -----| ----------- | ------------------- |
| [RepresentingInstitute](#RepresentingInstitute-lookup-from-this-Site) | Lookup | [Institute](#Institute) | 0/1 (optional) |
| [SiteDedicatedInvolvementRoles](#SiteDedicatedInvolvementRoles-refering-to-this-Site) | Referers | [InvolvementRole](#InvolvementRole) | * (multiple) |
| [Study](#Study-parent-of-this-Site) | Parent | [ResearchStudy](#ResearchStudy) | 0/1 (optional) |
| [SystemAssignments](#SystemAssignments-childs-of-this-Site) | Childs | [SiteRelatedSystemAssignment](#SiteRelatedSystemAssignment) | * (multiple) |

##### **RepresentingInstitute** (lookup from this Site)
Target Type: [Institute](#Institute)
Addressed by: [RepresentingInstituteUid](#SiteRepresentingInstituteUid-Field).
##### **SiteDedicatedInvolvementRoles** (refering to this Site)
Target: [InvolvementRole](#InvolvementRole)
##### **Study** (parent of this Site)
Target Type: [ResearchStudy](#ResearchStudy)
Addressed by: [ResearchStudyUid](#SiteResearchStudyUid-Field).
##### **SystemAssignments** (childs of this Site)
Target: [SiteRelatedSystemAssignment](#SiteRelatedSystemAssignment)




## SiteRelatedSystemAssignment


### Fields

| Name | Type | Required | Fix |
| ---- | ---- | -------- | --- |
| [SiteRelatedSystemAssignmentUid](#SiteRelatedSystemAssignmentSiteRelatedSystemAssignmentUid-Field) **(PK)** | *guid* | YES | no |
| [SystemEndpointUid](#SiteRelatedSystemAssignmentSystemEndpointUid-Field) (FK) | *guid* | YES | no |
| [SiteUid](#SiteRelatedSystemAssignmentSiteUid-Field) (FK) | *guid* | YES | no |
| [CustomRoles](#SiteRelatedSystemAssignmentCustomRoles-Field) | *string* | YES | no |
#### Unique Keys
* SiteRelatedSystemAssignmentUid **(primary)**

#### SiteRelatedSystemAssignment.**SiteRelatedSystemAssignmentUid** (Field)
* this field represents the identity (PK) of the record

#### SiteRelatedSystemAssignment.**SystemEndpointUid** (Field)
* this field is used as foreign key to address the related 'SystemEndpoint'

#### SiteRelatedSystemAssignment.**SiteUid** (Field)
* this field is used as foreign key to address the related 'Site'

#### SiteRelatedSystemAssignment.**CustomRoles** (Field)

semicolon separated list of custom role-names



### Relations

| Navigation-Name | Role | Target-Type | Target-Multiplicity |
| --------------- | -----| ----------- | ------------------- |
| [Site](#Site-parent-of-this-SiteRelatedSystemAssignment) | Parent | [Site](#Site) | 0/1 (optional) |
| [SystemEndpoint](#SystemEndpoint-lookup-from-this-SiteRelatedSystemAssignment) | Lookup | [SystemEndpoint](#SystemEndpoint) | 0/1 (optional) |
| [DedicatedSystemConnection](#DedicatedSystemConnection-refering-to-this-SiteRelatedSystemAssignment) | Referers | [SystemConnection](#SystemConnection) | * (multiple) |

##### **Site** (parent of this SiteRelatedSystemAssignment)
Target Type: [Site](#Site)
Addressed by: [SiteUid](#SiteRelatedSystemAssignmentSiteUid-Field).
##### **SystemEndpoint** (lookup from this SiteRelatedSystemAssignment)
Target Type: [SystemEndpoint](#SystemEndpoint)
Addressed by: [SystemEndpointUid](#SiteRelatedSystemAssignmentSystemEndpointUid-Field).
##### **DedicatedSystemConnection** (refering to this SiteRelatedSystemAssignment)
Target: [SystemConnection](#SystemConnection)




## StudyRelatedSystemAssignment


### Fields

| Name | Type | Required | Fix |
| ---- | ---- | -------- | --- |
| [StudyRelatedSystemAssignmentUid](#StudyRelatedSystemAssignmentStudyRelatedSystemAssignmentUid-Field) **(PK)** | *guid* | YES | no |
| [ResearchStudyUid](#StudyRelatedSystemAssignmentResearchStudyUid-Field) (FK) | *guid* | YES | no |
| [SystemEndpointUid](#StudyRelatedSystemAssignmentSystemEndpointUid-Field) (FK) | *guid* | YES | no |
| [CustomRoles](#StudyRelatedSystemAssignmentCustomRoles-Field) | *string* | YES | no |
#### Unique Keys
* StudyRelatedSystemAssignmentUid **(primary)**

#### StudyRelatedSystemAssignment.**StudyRelatedSystemAssignmentUid** (Field)
* this field represents the identity (PK) of the record

#### StudyRelatedSystemAssignment.**ResearchStudyUid** (Field)
* this field is used as foreign key to address the related 'ResearchStudy'

#### StudyRelatedSystemAssignment.**SystemEndpointUid** (Field)
* this field is used as foreign key to address the related 'SystemEndpoint'

#### StudyRelatedSystemAssignment.**CustomRoles** (Field)

semicolon separated list of custom role-names



### Relations

| Navigation-Name | Role | Target-Type | Target-Multiplicity |
| --------------- | -----| ----------- | ------------------- |
| [ResearchStudy](#ResearchStudy-parent-of-this-StudyRelatedSystemAssignment) | Parent | [ResearchStudy](#ResearchStudy) | 0/1 (optional) |
| [SystemEndpoint](#SystemEndpoint-lookup-from-this-StudyRelatedSystemAssignment) | Lookup | [SystemEndpoint](#SystemEndpoint) | 0/1 (optional) |

##### **ResearchStudy** (parent of this StudyRelatedSystemAssignment)
Target Type: [ResearchStudy](#ResearchStudy)
Addressed by: [ResearchStudyUid](#StudyRelatedSystemAssignmentResearchStudyUid-Field).
##### **SystemEndpoint** (lookup from this StudyRelatedSystemAssignment)
Target Type: [SystemEndpoint](#SystemEndpoint)
Addressed by: [SystemEndpointUid](#StudyRelatedSystemAssignmentSystemEndpointUid-Field).


