/* based on ORSCF VisitData Contract v1.9.1.11838 */


export class UidValueCriteria {
  
  /**
   * The value to match.
   */
  public value: string = '';
  
}

export class StringValueCriteria {
  
  /**
   * The value to match.
   */
  public value: string = '';
  
  /**
   * Enables, that the given value can just be a substring within the content of the target field. DEFAULT (if this is undefined or null) is 'false'.
   */
  public matchSubstring?: boolean;
  
}

/**
 * Declares, how the corresponding 'value' should be compared. DEFAULT (if this is undefined or null) is 'Equal'(1).
 */
export enum RangeMatchingBehaviour {
  /** Matching only the exactly given value. (DEFAULT) */
  Equal = 1,
  /** Matching all values lower than the given value. */
  Less = 2,
  /** Matching the given value or any value lower than it. */
  LessOrEqual = 3,
  /** Matching all values more than the given value. */
  More = 4,
  /** Matching the given value or any value more than it. */
  MoreOrEqual = 5
}

export class DateValueCriteria {
  
  /**
   * The value to match.
   */
  public value: Date = new Date();
  
  /**
   * Declares, how the corresponding 'value' should be compared. DEFAULT (if this is undefined or null) is 'Equal'(1).
   */
  public matchingBehaviour?: RangeMatchingBehaviour;
  
}

export class VisitMetaRecord {
  
  /**
   * An [Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) which can be generated by any origin system and is used to address this ORSCF conform data record in decentralized environments. Note that this Identity must not be changed any more!
   */
  public visitUid: string = '';
  
  public studyUid: string = '';
  
  public siteUid: string = '';
  
  /**
   * identity of the patient which is usually a pseudonym from a corr. 'IdentiyManagementSystem' (the exact semantic is defined per study) *this field has a max length of 100
   */
  public subjectIdentifier: string = '';
  
  /**
   * This is an internal managed field, which is related to the state of records dedicated to the database. It will be automatically set when a record is archived. A mapping during data import requires opt-in.
   */
  public isArchived: boolean = false;
  
  /**
   * This is an internal managed field (UNIX-Timestamp), which is related to the state of records dedicated to the database. It will be automatically set to the current time when a record is created, updated, archived or unarchived, but cannot be updated from outside and must not be mapped during data imports.
   */
  public modificationTimestampUtc: number = 0;
  
}

/**
 * Declares, which portion of the corresponding 'value' should be compared. DEFAULT (if this is undefined or null) is 'Date'(3).
 */
export enum DataEnrollmentValidationState {
  /** rejected manually */
  Invalid_Rejected = -1,
  /** the validation is outstanding */
  NotValidated = 0,
  /** validation successfull */
  Validated = 1,
  /** manulles queittieren von warnungen nötig */
  OnHold_DubiousContentData = 2,
  /** waiting for manual approval */
  OnHold_ManualApproval = 3,
  Invalid_UnassignableTarget = 11,
  Invalid_UnassignableTimeframe = 12,
  Invalid_AssignmentCollision = 13,
  /** schema is unknown */
  Invalid_UnsupportedSchema = 21,
  /** schema is known, but outdated and there is no compatibility any more */
  Invalid_OutdatedSchema = 22,
  /** the content has syntactical issues or has a missmatch to the addresses schema */
  Invalid_BadContentFormat = 23,
  /** the content/data is not plausible for the business logic */
  Invalid_BadData = 24
}

export class DataRecordingMetaRecord {
  
  /**
   * An [Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) which can be generated by any origin system and is used to address this ORSCF conform data record in decentralized environments. Note that this Identity must not be changed any more!
   */
  public dataRecordingUid: string = '';
  
  public visitUid: string = '';
  
  /**
   * This is an internal managed field, which is related to the state of records dedicated to the database. It will be automatically set when a record is archived. A mapping during data import requires opt-in.
   */
  public isArchived: boolean = false;
  
  /**
   * This is an internal managed field (UNIX-Timestamp), which is related to the state of records dedicated to the database. It will be automatically set to the current time when a record is created, updated, archived or unarchived, but cannot be updated from outside and must not be mapped during data imports.
   */
  public modificationTimestampUtc: number = 0;
  
}

export class CustomFieldDescriptor {
  
  public technicalName: string = '';
  
  public isRequired: boolean = false;
  
  public displayLabel: string = '';
  
  public inputDescription?: string;
  
  public defaultValue?: string;
  
  public presets?: string[];
  
  public presetsOnly?: boolean;
  
  public regularExpression?: string;
  
}

export class VisitFields extends VisitMetaRecord {
  
  /**
   * unique invariant name of the visit-procedure as defined in the 'StudyWorkflowDefinition' (originated from the sponsor)
   */
  public visitProcedureName: string = '';
  
  /**
   * unique title of the visit execution as defined in the 'StudyWorkflowDefinition' (originated from the sponsor)
   */
  public visitExecutionTitle: string = '';
  
  /**
   * the estimated date when the visit is scheduled for execution *this field is optional
   */
  public scheduledDateUtc?: Date;
  
  /**
   * the real date, when the visits was executed *this field is optional
   */
  public executionDateUtc?: Date;
  
  /**
   * 0=Unscheduled / 1=Sheduled / 2=Executed / 3=AbortDuringExecution / 4=Skipped / 5=Removed
   */
  public executionState: number = 0;
  
  /**
   * *this field is optional (use null as value)
   */
  public executingPerson?: string;
  
  /**
   * Custom fields as defined by the Service. Call 'GetCustomFieldDescriptors' to get information about supported/required fields. Any passed values for undefined fields will be ignored.
   */
  public customFields?: Object;
  
  /**
   * An [Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) which can be generated by any origin system and is used to address this ORSCF conform data record in decentralized environments. Note that this Identity must not be changed any more!
   */
  public visitUid: string = '';
  
  public studyUid: string = '';
  
  public siteUid: string = '';
  
  /**
   * identity of the patient which is usually a pseudonym from a corr. 'IdentiyManagementSystem' (the exact semantic is defined per study) *this field has a max length of 100
   */
  public subjectIdentifier: string = '';
  
  /**
   * This is an internal managed field, which is related to the state of records dedicated to the database. It will be automatically set when a record is archived. A mapping during data import requires opt-in.
   */
  public isArchived: boolean = false;
  
  /**
   * This is an internal managed field (UNIX-Timestamp), which is related to the state of records dedicated to the database. It will be automatically set to the current time when a record is created, updated, archived or unarchived, but cannot be updated from outside and must not be mapped during data imports.
   */
  public modificationTimestampUtc: number = 0;
  
}

/**
 * A structure containing HL7/FHIR-Ressources (JSON only) and the essential fields which are required to qualify a ORSCF record.
 */
export class VisitFhirRessourceContainer extends VisitMetaRecord {
  
  /**
   * a HL7 ['Appointment'](http://www.hl7.org/fhir/appointment.html) resource in json format
   */
  public appointmentRessource?: Object;
  
  /**
   * An [Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) which can be generated by any origin system and is used to address this ORSCF conform data record in decentralized environments. Note that this Identity must not be changed any more!
   */
  public visitUid: string = '';
  
  public studyUid: string = '';
  
  public siteUid: string = '';
  
  /**
   * identity of the patient which is usually a pseudonym from a corr. 'IdentiyManagementSystem' (the exact semantic is defined per study) *this field has a max length of 100
   */
  public subjectIdentifier: string = '';
  
  /**
   * This is an internal managed field, which is related to the state of records dedicated to the database. It will be automatically set when a record is archived. A mapping during data import requires opt-in.
   */
  public isArchived: boolean = false;
  
  /**
   * This is an internal managed field (UNIX-Timestamp), which is related to the state of records dedicated to the database. It will be automatically set to the current time when a record is created, updated, archived or unarchived, but cannot be updated from outside and must not be mapped during data imports.
   */
  public modificationTimestampUtc: number = 0;
  
}

export class BatchableVisitMutation {
  
  /**
   * unique invariant name of the visit-procedure as defined in the 'StudyWorkflowDefinition' (originated from the sponsor)
   */
  public visitProcedureName?: string;
  
  /**
   * unique title of the visit execution as defined in the 'StudyWorkflowDefinition' (originated from the sponsor)
   */
  public visitExecutionTitle?: string;
  
  /**
   * 0=Unscheduled / 1=Sheduled / 2=Executed / 3=AbortDuringExecution / 4=Skipped / 5=Removed
   */
  public executionState?: number;
  
  /**
   * *this field is optional (use null as value)
   */
  public executingPerson?: string;
  
  /**
   * Custom fields as defined by the Service. Call 'GetCustomFieldDescriptors' to get information about supported/required fields. Any passed values for undefined fields will be ignored.
   */
  public customFields?: Object;
  
}

export class UidFieldFilter {
  
  /**
   * Specifies one or more values to match. DEFAULT (if this is undefined or null) will include everything (but NULL) to enable filtering based on 'excluded values'. An empty array which just has no elements will be treaded as valid input and results in no value matching, so this only makes sense when including NULL instead (if supported). An array containing multiple elements, will require at least ONE of the criteria to match (OR-linked)!
   */
  public includedValues?: UidValueCriteria[];
  
  /**
   * Specifies one or more values to be removed from the result set which was evaulated using the 'included values'. DEFAULT (if this is undefined or null) will just leave the filtering based on 'included values'. An empty array which just has no elements will also be ignored. An array containing multiple elements, will require at least ONE of the criteria to match (OR-linked)!
   */
  public excludedValues?: UidValueCriteria[];
  
  /**
   * Negates the outcome of the whole filter. DEFAULT (if this is undefined or null) is 'false'.
   */
  public negate?: boolean;
  
}

export class StringFieldFilter {
  
  /**
   * Specifies one or more values to match. DEFAULT (if this is undefined or null) will include everything (but NULL) to enable filtering based on 'excluded values'. An empty array which just has no elements will be treaded as valid input and results in no value matching, so this only makes sense when including NULL instead (if supported). An array containing multiple elements, will require at least ONE of the criteria to match (OR-linked)!
   */
  public includedValues?: StringValueCriteria[];
  
  /**
   * Specifies one or more values to be removed from the result set which was evaulated using the 'included values'. DEFAULT (if this is undefined or null) will just leave the filtering based on 'included values'. An empty array which just has no elements will also be ignored. An array containing multiple elements, will require at least ONE of the criteria to match (OR-linked)!
   */
  public excludedValues?: StringValueCriteria[];
  
  /**
   * Enables, that the included and excluded values are processed case-insenstive. DEFAULT (if this is undefined or null) is 'false'.
   */
  public ignoreCasing?: boolean;
  
  /**
   * Negates the outcome of the whole filter. DEFAULT (if this is undefined or null) is 'false'.
   */
  public negate?: boolean;
  
}

export class IntegerValueCriteria {
  
  /**
   * The value to match.
   */
  public value: number = 0;
  
  /**
   * Declares, how the corresponding 'value' should be compared. DEFAULT (if this is undefined or null) is 'Equal'(1).
   */
  public matchingBehaviour?: RangeMatchingBehaviour;
  
}

export class DateFieldFilter {
  
  /**
   * Specifies one or more values to match. DEFAULT (if this is undefined or null) will include everything (but NULL) to enable filtering based on 'excluded values'. An empty array which just has no elements will be treaded as valid input and results in no value matching, so this only makes sense when including NULL instead (if supported). An array containing multiple elements, will require at least ONE of the criteria to match (OR-linked)!
   */
  public includedValues?: DateValueCriteria[];
  
  /**
   * Specifies one or more values to be removed from the result set which was evaulated using the 'included values'. DEFAULT (if this is undefined or null) will just leave the filtering based on 'included values'. An empty array which just has no elements will also be ignored. An array containing multiple elements, will require at least ONE of the criteria to match (OR-linked)!
   */
  public excludedValues?: DateValueCriteria[];
  
  /**
   * Negates the outcome of the whole filter. DEFAULT (if this is undefined or null) is 'false'.
   */
  public negate?: boolean;
  
}

export class DataRecordingFields extends DataRecordingMetaRecord {
  
  /**
   * unique invariant name of ths task-procedure as defined in the 'StudyWorkflowDefinition' (originated from the sponsor)
   */
  public dataRecordingName: string = '';
  
  /**
   * title of the task execution as defined in the 'StudyWorkflowDefinition' (originated from the sponsor)
   */
  public taskExecutionTitle: string = '';
  
  /**
   * the estimated date when the visit is scheduled *this field is optional
   */
  public scheduledDateTimeUtc?: Date;
  
  /**
   * the real time, when the data was recorded *this field is optional
   */
  public executionDateTimeUtc?: Date;
  
  /**
   * 0=Unscheduled / 1=Sheduled / 2=Executed / 3=AbortDuringExecution / 4=Skipped / 5=Removed
   */
  public executionState: number = 0;
  
  /**
   * schema-url of the data which were stored inside of the 'RecordedData' field
   */
  public dataSchemaUrl: string = '';
  
  /**
   * version of schema, which is addressed by the 'DataSchemaUrl'
   */
  public dataSchemaVersion: string = '';
  
  /**
   * 'FhirQuestionaire' / 'XML' / 'CSV' / 'Custom'
   */
  public dataSchemaKind: string = '';
  
  /**
   * Language of free-text information inside of the data content
   */
  public dataLanguage?: string;
  
  /**
   * additional notes regarding this dedcated execution (supplied by the execution person) *this field is optional (use null as value)
   */
  public notesRegardingOutcome?: string;
  
  /**
   * *this field is optional (use null as value)
   */
  public executingPerson?: string;
  
  /**
   * Custom fields as defined by the Service. Call 'GetCustomFieldDescriptors' to get information about supported/required fields. Any passed values for undefined fields will be ignored.
   */
  public customFields?: Object;
  
  /**
   * An [Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) which can be generated by any origin system and is used to address this ORSCF conform data record in decentralized environments. Note that this Identity must not be changed any more!
   */
  public dataRecordingUid: string = '';
  
  public visitUid: string = '';
  
  /**
   * This is an internal managed field, which is related to the state of records dedicated to the database. It will be automatically set when a record is archived. A mapping during data import requires opt-in.
   */
  public isArchived: boolean = false;
  
  /**
   * This is an internal managed field (UNIX-Timestamp), which is related to the state of records dedicated to the database. It will be automatically set to the current time when a record is created, updated, archived or unarchived, but cannot be updated from outside and must not be mapped during data imports.
   */
  public modificationTimestampUtc: number = 0;
  
}

export class VisitMutation extends BatchableVisitMutation {
  
  /**
   * the estimated date when the visit is scheduled for execution *this field is optional
   */
  public scheduledDateUtc?: Date;
  
  /**
   * the real date, when the visits was executed *this field is optional
   */
  public executionDateUtc?: Date;
  
  /**
   * unique invariant name of the visit-procedure as defined in the 'StudyWorkflowDefinition' (originated from the sponsor)
   */
  public visitProcedureName?: string;
  
  /**
   * unique title of the visit execution as defined in the 'StudyWorkflowDefinition' (originated from the sponsor)
   */
  public visitExecutionTitle?: string;
  
  /**
   * 0=Unscheduled / 1=Sheduled / 2=Executed / 3=AbortDuringExecution / 4=Skipped / 5=Removed
   */
  public executionState?: number;
  
  /**
   * *this field is optional (use null as value)
   */
  public executingPerson?: string;
  
  /**
   * Custom fields as defined by the Service. Call 'GetCustomFieldDescriptors' to get information about supported/required fields. Any passed values for undefined fields will be ignored.
   */
  public customFields?: Object;
  
}

export class IntegerFieldFilter {
  
  /**
   * Specifies one or more values to match. DEFAULT (if this is undefined or null) will include everything (but NULL) to enable filtering based on 'excluded values'. An empty array which just has no elements will be treaded as valid input and results in no value matching, so this only makes sense when including NULL instead (if supported). An array containing multiple elements, will require at least ONE of the criteria to match (OR-linked)!
   */
  public includedValues?: IntegerValueCriteria[];
  
  /**
   * Specifies one or more values to be removed from the result set which was evaulated using the 'included values'. DEFAULT (if this is undefined or null) will just leave the filtering based on 'included values'. An empty array which just has no elements will also be ignored. An array containing multiple elements, will require at least ONE of the criteria to match (OR-linked)!
   */
  public excludedValues?: IntegerValueCriteria[];
  
  /**
   * Negates the outcome of the whole filter. DEFAULT (if this is undefined or null) is 'false'.
   */
  public negate?: boolean;
  
}

export class DataRecordingStructure extends DataRecordingFields {
  
  /**
   * RAW data, in the schema as defined at the 'DataSchemaUrl'
   */
  public recordedData: string = '';
  
  /**
   * unique invariant name of ths task-procedure as defined in the 'StudyWorkflowDefinition' (originated from the sponsor)
   */
  public dataRecordingName: string = '';
  
  /**
   * title of the task execution as defined in the 'StudyWorkflowDefinition' (originated from the sponsor)
   */
  public taskExecutionTitle: string = '';
  
  /**
   * the estimated date when the visit is scheduled *this field is optional
   */
  public scheduledDateTimeUtc?: Date;
  
  /**
   * the real time, when the data was recorded *this field is optional
   */
  public executionDateTimeUtc?: Date;
  
  /**
   * 0=Unscheduled / 1=Sheduled / 2=Executed / 3=AbortDuringExecution / 4=Skipped / 5=Removed
   */
  public executionState: number = 0;
  
  /**
   * schema-url of the data which were stored inside of the 'RecordedData' field
   */
  public dataSchemaUrl: string = '';
  
  /**
   * version of schema, which is addressed by the 'DataSchemaUrl'
   */
  public dataSchemaVersion: string = '';
  
  /**
   * 'FhirQuestionaire' / 'XML' / 'CSV' / 'Custom'
   */
  public dataSchemaKind: string = '';
  
  /**
   * Language of free-text information inside of the data content
   */
  public dataLanguage?: string;
  
  /**
   * additional notes regarding this dedcated execution (supplied by the execution person) *this field is optional (use null as value)
   */
  public notesRegardingOutcome?: string;
  
  /**
   * *this field is optional (use null as value)
   */
  public executingPerson?: string;
  
  /**
   * Custom fields as defined by the Service. Call 'GetCustomFieldDescriptors' to get information about supported/required fields. Any passed values for undefined fields will be ignored.
   */
  public customFields?: Object;
  
  /**
   * An [Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) which can be generated by any origin system and is used to address this ORSCF conform data record in decentralized environments. Note that this Identity must not be changed any more!
   */
  public dataRecordingUid: string = '';
  
  public visitUid: string = '';
  
  /**
   * This is an internal managed field, which is related to the state of records dedicated to the database. It will be automatically set when a record is archived. A mapping during data import requires opt-in.
   */
  public isArchived: boolean = false;
  
  /**
   * This is an internal managed field (UNIX-Timestamp), which is related to the state of records dedicated to the database. It will be automatically set to the current time when a record is created, updated, archived or unarchived, but cannot be updated from outside and must not be mapped during data imports.
   */
  public modificationTimestampUtc: number = 0;
  
}

export class VisitStructure extends VisitFields {
  
  public dataRecordings?: DataRecordingStructure[];
  
  /**
   * unique invariant name of the visit-procedure as defined in the 'StudyWorkflowDefinition' (originated from the sponsor)
   */
  public visitProcedureName: string = '';
  
  /**
   * unique title of the visit execution as defined in the 'StudyWorkflowDefinition' (originated from the sponsor)
   */
  public visitExecutionTitle: string = '';
  
  /**
   * the estimated date when the visit is scheduled for execution *this field is optional
   */
  public scheduledDateUtc?: Date;
  
  /**
   * the real date, when the visits was executed *this field is optional
   */
  public executionDateUtc?: Date;
  
  /**
   * 0=Unscheduled / 1=Sheduled / 2=Executed / 3=AbortDuringExecution / 4=Skipped / 5=Removed
   */
  public executionState: number = 0;
  
  /**
   * *this field is optional (use null as value)
   */
  public executingPerson?: string;
  
  /**
   * Custom fields as defined by the Service. Call 'GetCustomFieldDescriptors' to get information about supported/required fields. Any passed values for undefined fields will be ignored.
   */
  public customFields?: Object;
  
  /**
   * An [Universally Unique Identifier](https://de.wikipedia.org/wiki/Universally_Unique_Identifier) which can be generated by any origin system and is used to address this ORSCF conform data record in decentralized environments. Note that this Identity must not be changed any more!
   */
  public visitUid: string = '';
  
  public studyUid: string = '';
  
  public siteUid: string = '';
  
  /**
   * identity of the patient which is usually a pseudonym from a corr. 'IdentiyManagementSystem' (the exact semantic is defined per study) *this field has a max length of 100
   */
  public subjectIdentifier: string = '';
  
  /**
   * This is an internal managed field, which is related to the state of records dedicated to the database. It will be automatically set when a record is archived. A mapping during data import requires opt-in.
   */
  public isArchived: boolean = false;
  
  /**
   * This is an internal managed field (UNIX-Timestamp), which is related to the state of records dedicated to the database. It will be automatically set to the current time when a record is created, updated, archived or unarchived, but cannot be updated from outside and must not be mapped during data imports.
   */
  public modificationTimestampUtc: number = 0;
  
}

export class VisitFilter {
  
  public studyUid?: UidFieldFilter;
  
  public siteUid?: UidFieldFilter;
  
  /**
   * identity of the patient which is usually a pseudonym from a corr. 'IdentiyManagementSystem' (the exact semantic is defined per study) *this field has a max length of 100
   */
  public subjectIdentifier?: StringFieldFilter;
  
  public visitProcedureName?: StringFieldFilter;
  
  /**
   * unique title of the visit execution as defined in the 'StudyWorkflowDefinition' (originated from the sponsor)
   */
  public visitExecutionTitle?: StringFieldFilter;
  
  /**
   * 0=Unscheduled / 1=Sheduled / 2=Executed / 3=AbortDuringExecution / 4=Skipped / 5=Removed
   */
  public executionState?: IntegerFieldFilter;
  
  public scheduledDateUtc?: DateFieldFilter;
  
  public executionDateUtc?: DateFieldFilter;
  
  /**
   * Custom fields as defined by the Service. Call 'GetCustomFieldDescriptors' to get information about supported/required fields. Any passed values for undefined fields will be ignored.
   */
  public customFields?: Object;
  
}
